<?php

error_reporting(E_ALL & E_STRICT);

/**
 * contains the database connection settings
 * @var array
 * @example $db_config = array ('string' => 'sqlite:memory', 'username' => 'foo', 'password' => 'bar');
 */
$db_config = array (
	'string' => "sqlite:database/simple.db.sqlite3",
	'username' => null,
	'password' => null);


/**
 * simple csv-to-database mapping
 * @var array
 */
$csv_schema = array (
	'booking_id',
	'date',
	'starttime',
	'endtime',
	'room',
	'event',
	'lecturer',
	'comment');

/**
 * the csv source file
 * @var string
 */
$csvSrcFile = 'datasources/roombooking.csv';


/**
 * maximum line length for fgets()
 * @var int
 */
const MAX_READ = 4096;


/**
 * the sql command to insert data, in a PDO::prepare()-format
 * @var string
 * @example $rawSqlInsert = 'INSERT INTO bookings (col1, col2) VALUES (:col1, :col2);
 */
$rawSqlInsert = 'INSERT INTO bookings (booking_id, date, starttime, endtime, room, event, lecturer, comment) VALUES (:booking_id, :date, :starttime, :endtime, :room, :event, :lecturer, :comment)';


// (1) Database connection
$db = null;
try 
{
	$db = new PDO($db_config['string'], $db_config['username'], $db_config['password']);
}
catch(Exception $e)
{
	die($e->getMessage()."\n");
}



// (2) open CSV file
$csv = null;
$csv = fopen($csvSrcFile, "r") or
	die ("could not open CSV file");

// skip header
fgets($csv, MAX_READ);



// (3) iterate over csv file
// prepare the SQL statement - an update of the variables
// will also update the statement.
$dbInsert = $db->prepare($rawSqlInsert);
$noDataLength = count($csv_schema)+20;
$srcLineNo = 0;
$lastIndex = 1;
while (!feof($csv))
{
	$line = fgets($csv, MAX_READ);

	// ignore empty lines
	if (empty($line) || strlen($line) <= $noDataLength)
	{
		$srcLineNo++;
		continue;
	}
	
	$csvData = explode(";", $line);
	$sqlData = array();
	
	// clean quotation marks
	foreach ($csv_schema as $index => $value)
		if (!empty($value))
			$sqlData[$value] = trim($csvData[$index], "\" \t\n\r\0\x0B");
	$sqlData['booking_id'] = $lastIndex;
	
	// insert data into database
	try {
		echo $srcLineNo."\t".implode("\t", $sqlData)."\n";
		if (!$dbInsert->execute($sqlData))
		{
			echo "error in line $srcLineNo:\n";
			var_dump($sqlData);
			$error = $db->errorInfo();
			echo "Error (".$error[1]."): ".$error[2]."\n";
			die();
		}
	}
	catch (Exception $e)
	{
		die($e->getMessage()."\n");
	}
	
	$srcLineNo++;
	$lastIndex++;
}



exit("all okay\n");


